@@ -22,9 +22,9 @@ class KanjiBrowser : public KXmlGuiWindow
 
   public:
          KanjiBrowser();
-        ~KanjiBrowser();
+        ~KanjiBrowser() override;
 
-  private slots:
+  private Q_SLOTS:
     /**
      * Change/update the status bar.
      */
