@@ -18,6 +18,9 @@ static const char version[] = "0.1";
 
 int main( int argc, char **argv )
 {
+  QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+  QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+
   QApplication app(argc, argv);
   app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kiten"), app.windowIcon()));
   KLocalizedString::setApplicationDomain("kiten");
